==> flash-1.1.0%2B1.tar.gz: README.md <==
# Flash

⚡️A highly customizable, powerful and easy-to-use alerting library for
Flutter.

### Specs
[![pub](https://img.shields.io/pub/v/flash.svg?style=flat)](https://pub.dev/packages/flash)


This library allows you to show messages or alerts in your app **quickly
and easily**. It can be used as an alternative to `Snackbar` or `Toast`
or `Dialog` and offers a plethora of useful features and customization
options for you to play with.

It has been written **100% in Dart**. ❤️

![](./doc/images/banner.png)

# Table of Contents
* [Getting started](#getting-started)
* [Sample Project](#sample-project)
* [Usage](#usage)
* [Roadmap](#roadmap)
* [Contribution](#contribution)
* [License](#license)

### Spread Some :heart:
[![GitHub followers](https://img.shields.io/github/followers/sososdk.svg?style=social&label=Follow)](https://github.com/sososdk)

# Getting started

In the `pubspec.yaml` of your flutter project, add the following
dependency:

```yaml
dependencies:
  ...
  flash: "^1.1.0"
```

In your library add the following import:

```dart
import 'package:flash/flash.dart';
```

# Sample Project
We have an exhaustive [sample project](./example) demonstrating almost
every feature of the library.

# Usage
It is recommended to check the sample project to get a complete
understanding of all the features offered by the library.

![basic](https://raw.githubusercontent.com/sososdk/tool/master/flash/basic.gif)
![top](https://raw.githubusercontent.com/sososdk/tool/master/flash/top.gif)
![bottom](https://raw.githubusercontent.com/sososdk/tool/master/flash/bottom.gif)
![toast](https://raw.githubusercontent.com/sososdk/tool/master/flash/toast.gif)
![dialog](https://raw.githubusercontent.com/sososdk/tool/master/flash/dialog.gif)

# Roadmap
These are some of the prioritized features in the pipeline awaiting to
be implemented in the near future


# Contribution

I highly encourage the community to step forward and improve this
library further. You can fix any reported bug, propose or implement new
features, write tests, etc.

Here is a quick list of things to remember
* Check the open issues before creating a new one,
* Help me in reducing the number of open issues by fixing any existing
  bugs,
* Check the roadmap to see if you can help in implementing any new
  feature,
* You can contribute by writing unit and integration tests for this
  library,
* If you have any new idea that aligns with the goal of this library,
  feel free to raise a feature request and discuss it.

# License

```
Copyright 2019 sososdk

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

==> flash-1.5.2%2B1.tar.gz: README.md <==
# Flash

⚡️A highly customizable, powerful and easy-to-use alerting library for
Flutter.

Website: [https://sososdk.github.io/flash](https://sososdk.github.io/flash)

### Specs
[![pub](https://img.shields.io/pub/v/flash.svg?style=flat)](https://pub.dev/packages/flash)


This library allows you to show messages or alerts in your app **quickly
and easily**. It can be used as an alternative to `Snackbar` or `Toast`
or `Dialog` and offers a plethora of useful features and customization
options for you to play with.

It has been written **100% in Dart**. ❤️

![](./doc/images/banner.png)

# Table of Contents
* [Getting started](#getting-started)
* [Sample Project](#sample-project)
* [Usage](#usage)
* [Roadmap](#roadmap)
* [Contribution](#contribution)
* [License](#license)

### Spread Some :heart:
[![GitHub followers](https://img.shields.io/github/followers/sososdk.svg?style=social&label=Follow)](https://github.com/sososdk)

# Getting started

In the `pubspec.yaml` of your flutter project, add the following dependency:

```yaml
dependencies:
  ...
  flash: ^1.5.2+1
```

In your library add the following import:

```dart
import 'package:flash/flash.dart';
```

# Sample Project
We have an exhaustive [sample project](./example) demonstrating almost
every feature of the library.

# Usage
It is recommended to check the sample project to get a complete
understanding of all the features offered by the library.

![basic](https://raw.githubusercontent.com/sososdk/tool/master/flash/basic.gif)
![top](https://raw.githubusercontent.com/sososdk/tool/master/flash/top.gif)
![bottom](https://raw.githubusercontent.com/sososdk/tool/master/flash/bottom.gif)
![toast](https://raw.githubusercontent.com/sososdk/tool/master/flash/toast.gif)
![dialog](https://raw.githubusercontent.com/sososdk/tool/master/flash/dialog.gif)

# Contribution

I highly encourage the community to step forward and improve this
library further. You can fix any reported bug, propose or implement new
features, write tests, etc.

Here is a quick list of things to remember
* Check the open issues before creating a new one,
* Help me in reducing the number of open issues by fixing any existing
  bugs,
* Check the roadmap to see if you can help in implementing any new
  feature,
* You can contribute by writing unit and integration tests for this
  library,
* If you have any new idea that aligns with the goal of this library,
  feel free to raise a feature request and discuss it.

# License

```
Copyright 2019 sososdk

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
